"""
presentation_instances.py
"""

population = [
    # Diagrams
    {'Name': 'default', 'Drawing type': 'Starr class diagram'},
    {'Name': 'diagnostic', 'Drawing type': 'Starr class diagram'},

    {'Name': 'default', 'Drawing type': 'Shlaer-Mellor class diagram'},
    {'Name': 'diagnostic', 'Drawing type': 'Shlaer-Mellor class diagram'},

    {'Name': 'default', 'Drawing type': 'xUML class diagram'},
    {'Name': 'diagnostic', 'Drawing type': 'xUML class diagram'},

    {'Name': 'default', 'Drawing type': 'xUML state machine diagram'},

    {'Name': 'default', 'Drawing type': 'Starr domain diagram'},
    {'Name': 'default', 'Drawing type': 'Starr class collaboration diagram'},

    {'Name': 'default', 'Drawing type': 'xUML domain diagram'},
    {'Name': 'default', 'Drawing type': 'xUML class collaboration diagram'},

    # Frames
    {'Name': 'default', 'Drawing type': 'OS Engineer large frame'},
    {'Name': 'default', 'Drawing type': 'OS Engineer medium frame'},
]